==> aws-cdk-scala_2.12-0.8.0-sources.jar: io/burkard/cdk/services/imagebuilder/CfnInfrastructureConfigurationProps.scala <==
package io.burkard.cdk.services.imagebuilder

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnInfrastructureConfigurationProps {

  def apply(
    name: String,
    instanceProfileName: String,
    keyPair: Option[String] = None,
    logging: Option[software.amazon.awscdk.services.imagebuilder.CfnInfrastructureConfiguration.LoggingProperty] = None,
    description: Option[String] = None,
    tags: Option[Map[String, String]] = None,
    securityGroupIds: Option[List[String]] = None,
    instanceTypes: Option[List[String]] = None,
    resourceTags: Option[Map[String, String]] = None,
    subnetId: Option[String] = None,
    terminateInstanceOnFailure: Option[Boolean] = None,
    instanceMetadataOptions: Option[software.amazon.awscdk.services.imagebuilder.CfnInfrastructureConfiguration.InstanceMetadataOptionsProperty] = None,
    snsTopicArn: Option[String] = None
  ): software.amazon.awscdk.services.imagebuilder.CfnInfrastructureConfigurationProps =
    (new software.amazon.awscdk.services.imagebuilder.CfnInfrastructureConfigurationProps.Builder)
      .name(name)
      .instanceProfileName(instanceProfileName)
      .keyPair(keyPair.orNull)
      .logging(logging.orNull)
      .description(description.orNull)
      .tags(tags.map(_.asJava).orNull)
      .securityGroupIds(securityGroupIds.map(_.asJava).orNull)
      .instanceTypes(instanceTypes.map(_.asJava).orNull)
      .resourceTags(resourceTags.map(_.asJava).orNull)
      .subnetId(subnetId.orNull)
      .terminateInstanceOnFailure(terminateInstanceOnFailure.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .instanceMetadataOptions(instanceMetadataOptions.orNull)
      .snsTopicArn(snsTopicArn.orNull)
      .build()
}

==> aws-cdk-scala_3-0.19.0-sources.jar: io/burkard/cdk/services/imagebuilder/CfnInfrastructureConfigurationProps.scala <==
package io.burkard.cdk.services.imagebuilder

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnInfrastructureConfigurationProps {

  def apply(
    name: String,
    instanceProfileName: String,
    keyPair: Option[String] = None,
    logging: Option[software.amazon.awscdk.services.imagebuilder.CfnInfrastructureConfiguration.LoggingProperty] = None,
    description: Option[String] = None,
    tags: Option[Map[String, String]] = None,
    securityGroupIds: Option[List[String]] = None,
    instanceTypes: Option[List[String]] = None,
    resourceTags: Option[Map[String, String]] = None,
    subnetId: Option[String] = None,
    terminateInstanceOnFailure: Option[Boolean] = None,
    instanceMetadataOptions: Option[software.amazon.awscdk.services.imagebuilder.CfnInfrastructureConfiguration.InstanceMetadataOptionsProperty] = None,
    snsTopicArn: Option[String] = None
  ): software.amazon.awscdk.services.imagebuilder.CfnInfrastructureConfigurationProps =
    (new software.amazon.awscdk.services.imagebuilder.CfnInfrastructureConfigurationProps.Builder)
      .name(name)
      .instanceProfileName(instanceProfileName)
      .keyPair(keyPair.orNull)
      .logging(logging.orNull)
      .description(description.orNull)
      .tags(tags.map(_.asJava).orNull)
      .securityGroupIds(securityGroupIds.map(_.asJava).orNull)
      .instanceTypes(instanceTypes.map(_.asJava).orNull)
      .resourceTags(resourceTags.map(_.asJava).orNull)
      .subnetId(subnetId.orNull)
      .terminateInstanceOnFailure(terminateInstanceOnFailure.map(Boolean.box).orNull)
      .instanceMetadataOptions(instanceMetadataOptions.orNull)
      .snsTopicArn(snsTopicArn.orNull)
      .build()
}
